@@ -24,9 +24,11 @@
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
 #include <stdlib.h>
+#include <locale.h>
 
 static gboolean diff_window = FALSE;
 static gboolean version = FALSE;
+static gchar **dirs = NULL;
 
 static GOptionEntry options[] = {
 	{ "diff", 'd',
@@ -34,7 +36,11 @@ static GOptionEntry options[] = {
 	  N_("Show the diff window"),
 	  NULL },
 	{ "version", 'v',
-	  0, G_OPTION_ARG_NONE, &version, N_("Show version"), NULL },
+	  0, G_OPTION_ARG_NONE, &version,
+	  N_("Show version information and exit"), NULL },
+	{ G_OPTION_REMAINING, '\0',
+	  0, G_OPTION_ARG_FILENAME_ARRAY, &dirs,
+	  NULL, N_("[DIRECTORY]") },
 	{ NULL }
 };
 
@@ -51,22 +57,24 @@ main (int    argc,
 	bindtextdomain (GETTEXT_PACKAGE, LOCALEDIR);
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
+	setlocale (LC_ALL, "");
 
 	g_thread_init (NULL);
 
 	gdk_threads_init ();
 	gdk_threads_enter ();
 
- 	context = g_option_context_new (_("[DIRECTORY]"));
-
-	description = g_strdup_printf (_("Report errors (in English, with LC_ALL=C) to <%s>."), PACKAGE_BUGREPORT);
-	g_option_context_set_summary (context, _("Giggle is a graphical frontend for the git directory tracker."));
-	g_option_context_set_description (context, description);
-	g_free (description);
+	context = g_option_context_new (NULL);
 
+	g_option_context_set_translation_domain (context, GETTEXT_PACKAGE);
 	g_option_context_add_main_entries (context, options, GETTEXT_PACKAGE);
 	g_option_context_add_group (context, gtk_get_option_group (TRUE));
 
+	description = g_strdup_printf (_("Report errors (in English, with LC_ALL=C) to <%s>."), PACKAGE_BUGREPORT);
+	g_option_context_set_summary (context, N_("Giggle is a graphical frontend for the git content tracker."));
+	g_option_context_set_description (context, description);
+	g_free (description);
+
 	if (!g_option_context_parse (context, &argc, &argv, &error)) {
 		char *basename = g_filename_display_basename (argv[0]);
 
@@ -97,15 +105,16 @@ main (int    argc,
 	g_set_application_name ("Giggle");
 	window = giggle_window_new ();
 
-	/* parse GIT_DIR into dir and unset it; if empty use the current_wd */
-	dir = g_strdup (g_getenv ("GIT_DIR"));
-
-	if (!dir || !*dir) {
-		g_free (dir);
-
-		if (argc > 1 && *argv[1]) {
-			dir = g_strdup (argv[1]);
-		} else {
+	/* Set dir to:
+	    - the first remaining arg, or
+	    - the value of GIT_DIR, or
+	    - the current working dir */
+	if (dirs && *dirs) {
+		dir = g_strdup (*dirs);
+		g_strfreev (dirs);
+	} else {
+		dir = g_strdup (g_getenv ("GIT_DIR"));
+		if (dir == NULL) {
 			dir = g_get_current_dir ();
 		}
 	}
